# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['manim_tikz']

package_data = \
{'': ['*']}

install_requires = \
['manim>=0.17.0']

entry_points = \
{'manim.plugins': ['manim_tikz = module:object.attr']}

setup_kwargs = {
    'name': 'manim-tikz',
    'version': '0.0.1a1',
    'description': 'Converts Tikz markup code into an SVGMobject for use in manim.',
    'long_description': '# Manim Tikz\n\nConverts Tikz markup code into an `SVGMobject` for use in `manim`.\n\n# Installation\n\n`manim-tikz` requires `manim` version `0.17.0` and above, which uses the `svgelements` library for SVG rendering, as this changes how SVG images are rendered. `manim-tikz` be installed from PyPI using `pip`:\n\n```py\npip install manim-tikz\n```\n\n# Usage\n\n`manim-tikz` adds the subclass `Tikz` to the `manim` class `SVGMobject`, as well as the subclass `TikzTemplate` to the `manim` class `TexTemplate` behind the scenes for `Tikz` to use.\n\nTo convert Tikz markup code into an `SVGMobject`, import `Tikz` from the `manim-tikz` library:\n\n```py\nfrom manim import *\nfrom manim-tikz import Tikz\n```\n\nThen when constructing a `Scene` in `manim`, define a `Tikz` object like so:\n\n```py\ntikz_image = Tikz(code, [packages], [libaries], [tikzset], preamble, use_pdf)\n```\n\n- **`code`**: The Tikz code to render, as a `string`.\n- **`[packages]`** *(optional)*: A list of `string` for additional LaTeX packages to include in the preamble, added using the `\\usepackage` command. For example, if you include any special fonts or symbols in your Tikz picture, like `marvosym`.\n- **`[libraries]`** *(optional)*: A list of `string` for any Tikz libraries you require to render your Tikz picture, such as `positioning`, `arrows.meta` or `calc`. These will be added to the preamble using the `\\usetikzlibrary` command.\n- **`[tikzset]`** *(optional)*: A list of `string` for any style definitions and similar you want to define before the Tikz picture (see the Tikz/PGF package [manual](https://tikz.dev]) for further details). Added to the preamble using the `\\tikzset` command.\n- **`preamble`** *(optional)*: A `string` for any other commands you wish to add to the preamble, such as setting up package options. Be careful, making a mistake here can easily result in errors!\n- **`use_pdf`** *(optional, `False` by default)*: By default, `manim-tikz` will render the Tikz markup to a DVI file, which is then imported into `manim`. However, some drawing commands generated by Tikz do not render properly in DVI and require postscript (PDF). Setting this option to `True` will render to a PDF file instead, so use this option if there are problems with the output.\n\n# Example\n\n```py\nfrom manim import *\nfrom manim_tikz import Tikz\n\nclass TikzScene(Scene):\n    def construct(self):\n\n        test_tex = Tikz(r"\\draw[magenta, line width=10mm, fill=blue] (0,0) rectangle(1,1);", use_pdf=False)\n\n        self.add(test_tex)\n```\n\n![manim-tikz](https://github.com/ralphieraccoon/manim-tikz/blob/master/media/images/example/TikzScene_ManimCE_v0.17.0.png?raw=true)\n\n# Animation\n\nLike any other `SVGMobject`, `manim` can animate these images using the same animation functions. You might get some rather bizarre results depending on how the drawing order has been interpreted, but they generally look nice. \n\nFuture implementations of this plugin may try to include animated Tikz images using the `animate` library in Tikz, I\'ll have to look further into how `manim` handles animated SVG images.\n\n# Issues\n\n## Line Thickness\n\nAt the moment it seems that the default line thickness for TikZ is almost imperceptibly thin when rendered in `manim`. Not sure why this happens, but you may want to consider increasing `line width` in your Tikz images.\n\n## Fadings, Gradients, Shadows etc.\n\nI haven\'t yet tested the library using any of these Tikz features, so I don\'t know how well they will work in `manim`. I\'ll look at making some tests in the future.\n\n',
    'author': 'Ralphie Raccoon',
    'author_email': 'damian.crosby@manchester.ac.uk',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/ralphieraccoon/manim-tikz',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<3.12',
}


setup(**setup_kwargs)
